% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fit_and_reporting.R
\name{plot.MxModel}
\alias{plot.MxModel}
\alias{plot}
\alias{umxPlot}
\title{Create and display a graphical path diagram for a model.}
\usage{
\method{plot}{MxModel}(x = NA, std = FALSE, digits = 2,
  file = "name", pathLabels = c("none", "labels", "both"),
  fixed = TRUE, means = TRUE, resid = c("circle", "line", "none"),
  strip_zero = TRUE, showMeans = "deprecated",
  showFixed = "deprecated", ...)
}
\arguments{
\item{x}{An \code{\link{mxModel}} from which to make a path diagram}

\item{std}{Whether to standardize the model (default = FALSE).}

\item{digits}{The number of decimal places to add to the path coefficients}

\item{file}{The name of the dot file to write: NA = none; "name" = use the name of the model}

\item{pathLabels}{Whether to show labels on the paths. both will show both the parameter and the label. ("both", "none" or "labels")}

\item{fixed}{Whether to show fixed paths (defaults to TRUE)}

\item{means}{Whether to show means or not (default = TRUE)}

\item{resid}{How to show residuals and variances default is "circle". Options are "line" & "none"}

\item{strip_zero}{Whether to strip the leading "0" and decimal point from parameter estimates (default = TRUE)}

\item{showMeans}{Deprecated: just use 'means = TRUE'}

\item{showFixed}{Deprecated: just use 'fixed = TRUE'}

\item{...}{Optional parameters}
}
\description{
plot() produces SEM diagrams in graphviz format, and relies on \code{\link{DiagrammeR}} (or a 
graphviz application) to create the image. 
The commercial application \dQuote{OmniGraffle} is great for editing these images.
}
\details{
On unix and windows, \code{\link{plot}}() will create a pdf and open it in your default pdf reader.

\emph{Note:} DiagrammeR is supported out of the box.  By default, plots open in your browser.

If you use umx_set_plot_format("graphviz"), they will open in a graphviz helper app (if installed).
If you use graphviz, we try and use that app, but YOU HAVE TO INSTALL IT!
On OS X we try and open an app: you may need to associate the \sQuote{.gv}
extension with the graphviz app.
Find the .gv file made by plot, get info (cmd-I), then choose \dQuote{open with}, 
select graphviz.app (or OmniGraffle professional),
then set \dQuote{change all}.
}
\examples{
require(umx)
data(demoOneFactor)
latents  = c("G")
manifests = names(demoOneFactor)
m1 <- umxRAM("One Factor", data = mxData(cov(demoOneFactor), type = "cov", numObs = 500),
	umxPath(latents, to = manifests),
	umxPath(var = manifests),
	umxPath(var = latents, fixedAt = 1)
)
plot(m1)
plot(m1, std = TRUE, resid = "line", digits = 3, strip_zero = FALSE)
}
\references{
- \url{https://www.github.com/tbates/umx}, \url{https://en.wikipedia.org/wiki/DOT_(graph_description_language)}
}
\seealso{
- \code{\link{umx_set_plot_format}}, \code{\link{plot.MxModel}}, \code{\link{umxPlotACE}}, \code{\link{umxPlotCP}}, \code{\link{umxPlotIP}}, \code{\link{umxPlotGxE}}

Other Core Modeling Functions: \code{\link{umxAlgebra}},
  \code{\link{umxMatrix}}, \code{\link{umxModify}},
  \code{\link{umxPath}}, \code{\link{umxRAM}},
  \code{\link{umxRun}}, \code{\link{umxSuperModel}},
  \code{\link{umx}}

Other Plotting functions: \code{\link{umxPlotACEcov}},
  \code{\link{umxPlotACEv}}, \code{\link{umxPlotACE}},
  \code{\link{umxPlotCPnew}}, \code{\link{umxPlotCP}},
  \code{\link{umxPlotGxEbiv}}, \code{\link{umxPlotGxE}},
  \code{\link{umxPlotIP}}, \code{\link{umxPlotSimplex}},
  \code{\link{umx}}
}
\concept{Core Modeling Functions}
\concept{Plotting functions}
