% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/umx_build_umxACEv.R
\name{umxPlotACEv}
\alias{umxPlotACEv}
\alias{plot.MxModelACEv}
\title{Produce a graphical display of an ACE variance-components twin model}
\usage{
umxPlotACEv(x = NA, file = "name", digits = 2, means = FALSE,
  std = TRUE, strip_zero = TRUE, ...)
}
\arguments{
\item{x}{\code{\link{umxACEv}} model to plot.}

\item{file}{The name of the dot file to write: Default ("name") = use the name of the model. NA = don't plot.}

\item{digits}{How many decimals to include in path loadings (default = 2)}

\item{means}{Whether to show means paths (default = FALSE)}

\item{std}{Whether to standardize the model (default = FALSE)}

\item{strip_zero}{Whether to strip the leading "0" and decimal point from parameter estimates (default = TRUE)}

\item{...}{Additional (optional) parameters}
}
\value{
- optionally return the dot code
}
\description{
Plots an ACE model graphically, opening the result in the browser (or a graphviz application).
}
\examples{
require(umx)
data(twinData)
selDVs = "bmi"
mzData <- subset(twinData, zygosity == "MZFF")
dzData <- subset(twinData, zygosity == "DZFF")
m1 = umxACEv(selDVs = selDVs, dzData = dzData, mzData = mzData, sep = "")
plot(m1, std = FALSE) # don't standardize
}
\references{
- \url{https://www.github.com/tbates/umx}
}
\seealso{
Other Plotting functions: \code{\link{plot.MxModel}},
  \code{\link{umxPlotACEcov}}, \code{\link{umxPlotACE}},
  \code{\link{umxPlotCPnew}}, \code{\link{umxPlotCP}},
  \code{\link{umxPlotGxEbiv}}, \code{\link{umxPlotGxE}},
  \code{\link{umxPlotIP}}, \code{\link{umxPlotSimplex}},
  \code{\link{umx}}

Other Reporting functions: \code{\link{RMSEA.MxModel}},
  \code{\link{RMSEA.summary.mxmodel}}, \code{\link{RMSEA}},
  \code{\link{extractAIC.MxModel}}, \code{\link{loadings}},
  \code{\link{residuals.MxModel}},
  \code{\link{umxCI_boot}}, \code{\link{umxCI}},
  \code{\link{umxCompare}}, \code{\link{umxConfint}},
  \code{\link{umxExpCov}}, \code{\link{umxExpMeans}},
  \code{\link{umxFitIndices}},
  \code{\link{umxSummary.MxModel}},
  \code{\link{umxSummaryACEv}},
  \code{\link{umxSummaryACE}},
  \code{\link{umxSummarySexLim}},
  \code{\link{umxSummarySimplex}},
  \code{\link{umx_drop_ok}},
  \code{\link{umx_standardize_RAM}}
}
\concept{Plotting functions}
\concept{Reporting functions}
