% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/misc_and_utility.R
\name{umx_var}
\alias{umx_var}
\title{Get variances from a df that might contain some non-numeric columns}
\usage{
umx_var(df, ordVar = 1, format = c("full", "diag", "lower"),
  use = c("complete.obs", "pairwise.complete.obs", "everything",
  "all.obs", "na.or.complete"), digits = NULL, strict = TRUE)
}
\arguments{
\item{df}{A dataframe of raw data from which to get variances.}

\item{ordVar}{The value to return at any ordinal columns (defaults to 1).}

\item{format}{to return: options are c("full", "diag", "lower"). Defaults to full, but this is not implemented yet.}

\item{use}{Passed to \code{\link{cov}} - defaults to "complete.obs" (see param default for other options).}

\item{digits}{Ignored if NULL. Set for easy printing.}

\item{strict}{Whether to allow non-ordered factors to be processed (default = FALSE (no)).}
}
\value{
- \code{\link{mxModel}}
}
\description{
Pass in any dataframe and get variances despite some non-numeric columns.
Cells involving these non-numeric columns are set to ordVar (default = 1).
}
\examples{
tmp     = mtcars[,1:4]
tmp$cyl = ordered(mtcars$cyl) # ordered factor
tmp$hp  = ordered(mtcars$hp)  # binary factor
umx_var(tmp, format = "diag", ordVar = 1, use = "pair")
tmp2 = tmp[, c(1, 3)]
umx_var(tmp2, format = "diag")
umx_var(tmp2, format = "full")
}
\references{
- \url{https://tbates.github.io}
}
\seealso{
Other Miscellaneous Stats Helpers: \code{\link{reliability}},
  \code{\link{umxCov2cor}}, \code{\link{umxHetCor}},
  \code{\link{umx_apply}}, \code{\link{umx_cor}},
  \code{\link{umx_fun_mean_sd}}, \code{\link{umx_means}},
  \code{\link{umx_r_test}}, \code{\link{umx_round}},
  \code{\link{umx}}
}
\concept{Miscellaneous Stats Helpers}
