% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/xmu.R
\name{xmu_safe_run_summary}
\alias{xmu_safe_run_summary}
\title{Safely run and summarize a model}
\usage{
xmu_safe_run_summary(model1, model2 = NULL, autoRun = TRUE,
  tryHard = c("no", "mxTryHard", "mxTryHardOrdinal",
  "mxTryHardWideSearch"), summary = TRUE, comparison = TRUE)
}
\arguments{
\item{model1}{The model to attempt to run and summarize.}

\item{model2}{Optional second model to compare with model1.}

\item{autoRun}{Whether to run or not (default = TRUE) Options are FALSE and "if needed".}

\item{tryHard}{optionally tryHard (default 'no' uses normal mxRun). c("no", "mxTryHard", "mxTryHardOrdinal", "mxTryHardWideSearch")}

\item{summary}{Whether to print model summary (default = autoRun).}

\item{comparison}{Toggle to allow not making comparison, even if second model is provided (more flexible in programming).}
}
\value{
\itemize{
\item \code{\link{mxModel}}
}
}
\description{
The main benefit is that it returns the model, even if it can't be run.

The function will run the model if requested, wrapped in \code{\link[=tryCatch]{tryCatch()}} to avoid throwing an error.
If summary = TRUE then \code{\link[=umxSummary]{umxSummary()}} is requested (again, wrapped in try).

\emph{note}: If autoRun is logical, then it over-rides summary to match autoRun. This is useful for easy use umxRAM and twin models.
}
\examples{
# xmu_safe_run_summary(model, autoRun = FALSE, summary = TRUE, comparison= FALSE)
# xmu_safe_run_summary(model, model2, autoRun = TRUE, summary = TRUE, comparison= FALSE)
# xmu_safe_run_summary(model, model2, autoRun = TRUE)
}
\seealso{
\itemize{
\item \code{\link{mxTryHard}}
}

Other xmu internal not for end user: \code{\link{umxModel}},
  \code{\link{umx}}, \code{\link{xmuHasSquareBrackets}},
  \code{\link{xmuLabel_MATRIX_Model}},
  \code{\link{xmuLabel_Matrix}},
  \code{\link{xmuLabel_RAM_Model}}, \code{\link{xmuMI}},
  \code{\link{xmuMakeDeviationThresholdsMatrices}},
  \code{\link{xmuMakeOneHeadedPathsFromPathList}},
  \code{\link{xmuMakeTwoHeadedPathsFromPathList}},
  \code{\link{xmuMaxLevels}}, \code{\link{xmuMinLevels}},
  \code{\link{xmuPropagateLabels}},
  \code{\link{xmu_assemble_twin_supermodel}},
  \code{\link{xmu_check_levels_identical}},
  \code{\link{xmu_dot_make_paths}},
  \code{\link{xmu_dot_make_residuals}},
  \code{\link{xmu_make_mxData}},
  \code{\link{xmu_make_top_twin_models}},
  \code{\link{xmu_set_sep_from_suffix}},
  \code{\link{xmu_simplex_corner}},
  \code{\link{xmu_start_value_list}},
  \code{\link{xmu_starts}}
}
\concept{xmu internal not for end user}
